@@ -52,12 +52,4 @@ class DataArrayPlot(pg.PlotWidget):
     def __init__(self, parent=None, plotItem=None) -> None:
         super(DataArrayPlot, self).__init__(parent, plotItem)
 
-# ----------------------------------------------------------------------------------
-
-app = pg.mkQApp()
-imv = pg.ImageView(view=pg.PlotItem())
-imv.view.setLabels(bottom = "X Axis", 
-                     left = "Y1 Axis", 
-                     right = "Y2 Axis")
-imv.show()
-app.exec_()
\ No newline at end of file
+# ----------------------------------------------------------------------------------
\ No newline at end of file
